@@ -8,6 +8,7 @@ from lxml import etree, html
 from lxml.etree import XMLSyntaxError
 from lxml.html import HtmlElement, fromstring, html5parser, tostring
 from lxml.html.clean import Cleaner
+from requests import Response
 
 try:
     # Use cchardet for performance to detect the character encoding.
@@ -37,7 +38,7 @@ def get_html_from_element(element):
     return tostring(element)
 
 
-def get_html5_parsed_text(text):
+def get_html5_parsed_text(text: str) -> HtmlElement:
     """Return content using the html5parser, ideal for faulty html.
 
     This dance is slightly different than usual because it uses the
@@ -50,7 +51,7 @@ def get_html5_parsed_text(text):
     :param text: The html of the document
     :return: an lxml.HtmlElement object
     """
-    parsed = html5parser.document_fromstring(text.encode("utf-8"))
+    parsed = html5parser.document_fromstring(text)
     return fromstring(tostring(parsed, encoding="unicode"))
 
 
@@ -275,3 +276,11 @@ def fix_links_in_lxml_tree(link, keep_anchors=False):
         return url
     else:
         return url.split("#")[0]
+
+
+def is_html(response: Response) -> bool:
+    """Determines whether the item downloaded is an HTML document or something
+    else."""
+    if "text/html" in response.headers.get("content-type", ""):
+        return True
+    return False
