@@ -16,7 +16,7 @@ SMALL = r"a|an|and|as|at|but|by|en|for|if|in|is|of|on|or|the|to|v\.?|via|vs\.?"
 NUMS = "0123456789"
 PUNCT = r"""!"#$¢%&'‘()*+,\-./:;?@[\\\]_—`{|}~"""
 WEIRD_CHARS = r"¼½¾§ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÑÒÓÔÕÖØÙÚÛÜßàáâãäåæçèéêëìíîïñòóôœõöøùúûüÿ"
-BIG_WORDS = re.compile(fr"^({BIG})[{PUNCT}]?$", re.I | re.U)
+BIG_WORDS = re.compile(rf"^({BIG})[{PUNCT}]?$", re.I | re.U)
 SMALL_WORDS = re.compile(r"^(%s)$" % SMALL, re.I)
 SMALL_WORD_INLINE = re.compile(r"(^|\s)(%s)(\s|$)" % SMALL, re.I | re.U)
 INLINE_PERIOD = re.compile(r"[a-z][.][a-z]", re.I)
@@ -24,11 +24,11 @@ INLINE_SLASH = re.compile(r"[a-z][/][a-z]", re.I)
 INLINE_AMPERSAND = re.compile(r"([a-z][&][a-z])(.*)", re.I)
 UC_ELSEWHERE = re.compile(r"[%s]*?[a-zA-Z]+[A-Z]+?" % PUNCT, re.U)
 CAPFIRST = re.compile(r"^[%s]*?([A-Za-z])" % PUNCT)
-SMALL_FIRST = re.compile(fr"^([{PUNCT}]*)({SMALL})\b", re.I | re.U)
-SMALL_LAST = re.compile(fr"\b({SMALL})[{PUNCT}]?$", re.I | re.U)
+SMALL_FIRST = re.compile(rf"^([{PUNCT}]*)({SMALL})\b", re.I | re.U)
+SMALL_LAST = re.compile(rf"\b({SMALL})[{PUNCT}]?$", re.I | re.U)
 SUBPHRASE = re.compile(r"([:;?!][ ])(%s)" % SMALL)
 APOS_SECOND = re.compile(r"^[dol]{1}['‘]{1}[a-z]+$", re.I)
-ALL_CAPS = re.compile(fr"^[A-Z\s{PUNCT}{WEIRD_CHARS}{NUMS}]+$")
+ALL_CAPS = re.compile(rf"^[A-Z\s{PUNCT}{WEIRD_CHARS}{NUMS}]+$")
 UC_INITIALS = re.compile(r"^(?:[A-Z]{1}\.{1}|[A-Z]{1}\.{1}[A-Z]{1})+,?$")
 MAC_MC = re.compile(r"^([Mm]a?c)(\w+.*)")
 
