@@ -11,6 +11,6 @@ from juriscraper.opinions.united_states.state import ariz
 
 class Site(ariz.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.url = "http://www.azcourts.gov/opinions/SearchOpinionsMemoDecs.aspx?court=998"
