@@ -1,14 +1,16 @@
 # Auth: mlr
 # Date: 2013-04-26
 
-from juriscraper.opinions.united_states.state import miss
 from datetime import date
+
 from lxml import html
 
+from juriscraper.opinions.united_states.state import miss
+
 
 class Site(miss.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
 
         # If it's the beginning of January, we need to make sure that we aren't
