@@ -956,13 +956,17 @@ class DocketReport(BaseDocketReport, BaseReport):
         for row in docket_entry_rows:
             de = {}
             cells = row.xpath("./td[not(./input)]")
+            if len(cells) == 0:
+                # In some instances, the document entry table has an empty row
+                # <tr></tr>. See docket bankruptcy wiwb examples.
+                continue
             if len(cells) == 4:
                 # In some instances, the document entry table has an extra
                 # column. See almb, 92-04963
                 del cells[1]
 
             date_filed_str = force_unicode(cells[0].text_content())
-            if not date_filed_str:
+            if not date_filed_str.strip():
                 # Some older dockets have missing dates. Press on.
                 continue
             de["date_filed"] = convert_date_string(date_filed_str)
