@@ -1,7 +1,9 @@
 import email
 import re
 from datetime import date
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Optional, TypedDict, Union
+
+from lxml.html import HtmlElement
 
 from ..lib.string_utils import clean_string, convert_date_string, harmonize
 from .docket_report import BaseDocketReport
@@ -14,40 +16,72 @@ from .utils import (
 )
 
 
+class DocketEntryType(TypedDict):
+    date_filed: date
+    description: str
+    document_number: Optional[str]
+    document_url: Optional[str]
+    pacer_case_id: Optional[str]
+    pacer_doc_id: Optional[str]
+    pacer_magic_num: Optional[str]
+    pacer_seq_no: Optional[str]
+
+
+class DocketType(TypedDict):
+    case_name: str
+    date_filed: date
+    docket_entries: List[DocketEntryType]
+    docket_number: str
+
+
 class NotificationEmail(BaseDocketReport, BaseReport):
     """A BaseDocketReport for parsing PACER notification email parsing"""
 
+    ERROR_STRINGS = ["Notice of Electronic Claims Filing"]
+
     def __init__(self, court_id):
         self.court_id = court_id
         self.content_type = None
+        self.appellate = None
+        self.docket_numbers = []
         super().__init__(court_id)
 
     @property
     def data(self):
+        if self.is_valid is False or self.tree is None:
+            return {}
         base = {
             "court_id": self.court_id,
         }
-        parsed = {}
-        if self.tree is not None:
-            if self.content_type == "text/plain":
-                parsed = {
-                    "case_name": self._get_case_name_plain(),
-                    "docket_number": self._get_docket_number_plain(),
-                    "date_filed": self._get_date_filed(),
-                    "docket_entries": self._get_docket_entries(),
-                    "email_recipients": self._get_email_recipients_plain(),
-                }
-            else:
-                parsed = {
-                    "case_name": self._get_case_name(),
-                    "docket_number": self._get_docket_number(),
-                    "date_filed": self._get_date_filed(),
-                    "docket_entries": self._get_docket_entries(),
-                    "email_recipients": self._get_email_recipients(),
-                }
-
+        if self.content_type == "text/plain":
+            parsed = {
+                "appellate": self._is_appellate(),
+                "contains_attachments": self._contains_attachments_plain(),
+                "dockets": self._get_dockets(),
+                "email_recipients": self._get_email_recipients_plain(),
+            }
+        else:
+            parsed = {
+                "appellate": self._is_appellate(),
+                "contains_attachments": self._contains_attachments(),
+                "dockets": self._get_dockets(),
+                "email_recipients": self._get_email_recipients(),
+            }
         return {**base, **parsed}
 
+    def _is_appellate(self) -> bool:
+        """Gets the email notice type from the email text.
+
+        :returns: True if is an NDA otherwise False
+        """
+        if self.appellate is None:
+            if "Notice of Docket Activity" in self.tree.text_content():
+                self.appellate = True
+                return self.appellate
+            self.appellate = False
+            return self.appellate
+        return self.appellate
+
     def _sibling_path(self, label):
         """Gets the path string for the sibling of a label cell (td)
 
@@ -57,17 +91,18 @@ class NotificationEmail(BaseDocketReport, BaseReport):
         :param label: The cell label
         :returns: The Xpath to the next cell
         """
-        return f'//td[contains(., "{label}:")]/following-sibling::td[1]'
+        return f'.//td[contains(., "{label}:")]/following-sibling::td[1]'
 
-    def _get_case_name(self) -> str:
+    def _get_case_name(self, current_node: HtmlElement) -> str:
         """Gets a cleaned case name from the email text
 
+        :param  current_node: The relative lxml.HtmlElement
         :returns: Case name, cleaned and harmonized
         """
         path = self._sibling_path("Case Name")
-        case_name = self._xpath_text_0(self.tree, path)
+        case_name = self._xpath_text_0(current_node, path)
         if not case_name:
-            case_name = self._xpath_text_0(self.tree, f"{path}/p")
+            case_name = self._xpath_text_0(current_node, f"{path}/p")
             if not case_name:
                 case_name = "Unknown Case Title"
         return clean_string(harmonize(case_name))
@@ -75,29 +110,45 @@ class NotificationEmail(BaseDocketReport, BaseReport):
     def _get_case_name_plain(self) -> str:
         """Gets a cleaned case name from the plain email text
 
+        Raise an exception if a potential multi-docket text/plain notification
+        is found so we can get the example and add support for it.
+
         :returns: Case name, cleaned and harmonized
         """
         email_body = self.tree.text_content()
         regex = r"Case Name:(.*)"
         find_case = re.findall(regex, email_body)
+        if len(find_case) > 1:
+            raise NotImplementedError(
+                f"Received a potential multi-docket text/plain notification. "
+                f"This is probably our chance to add support for it. "
+                f"court: {self.court_id}"
+            )
         if find_case:
             case_name = find_case[0]
         else:
             case_name = "Unknown Case Title"
         return clean_string(harmonize(case_name))
 
-    def _get_docket_number(self) -> str:
+    def _get_docket_number(self, current_node: HtmlElement) -> str:
         """Gets a docket number from the email text
 
+        :param  current_node: The relative lxml.HtmlElement
         :returns: Docket number, parsed
         """
+
+        if self._is_appellate():
+            path = self._sibling_path("Case Number")
+            case_number = self._xpath_text_0(current_node, f"{path}/a")
+            return case_number
+
         path = self._sibling_path("Case Number")
         docket_number = self._parse_docket_number_strs(
-            self.tree.xpath(f"{path}/a/text()")
+            current_node.xpath(f"{path}/a/text()")
         )
         if not docket_number:
             docket_number = self._parse_docket_number_strs(
-                self.tree.xpath(f"{path}/p/a/text()")
+                current_node.xpath(f"{path}/p/a/text()")
             )
         return docket_number
 
@@ -117,22 +168,24 @@ class NotificationEmail(BaseDocketReport, BaseReport):
         :returns: Date filed as date object
         """
         date_filed = re.search(
-            r"filed\son\s([\d|\/]*)",
-            clean_string(self.tree.text_content()),
-            flags=re.IGNORECASE,
+            r"filed\son\s([\d|\/]*)", clean_string(self.tree.text_content())
         )
         return convert_date_string(
             date_filed[0].lower().replace("filed on ", "")
         )
 
-    def _get_document_number(self) -> str:
+    def _get_document_number(self, current_node: HtmlElement) -> str:
         """Gets the specific document number the notification is referring to
 
+        :param  current_node: The relative lxml.HtmlElement
         :returns: Document number, cleaned
         """
         path = self._sibling_path("Document Number")
-        text = self.tree.xpath(path)[0].text_content()
-        words = re.split(r"\(|\s", clean_string(text))
+        node = current_node.xpath(path)[0].text_content()
+        text_number = clean_string(node)
+        if text_number == "No document attached":
+            return None
+        words = re.split(r"\(|\s", text_number)
         return words[0]
 
     def _get_document_number_plain(self) -> str:
@@ -148,37 +201,78 @@ class NotificationEmail(BaseDocketReport, BaseReport):
         else:
             return None
 
-    def _get_doc1_anchor(self) -> str:
+    def _get_doc1_anchor(self, current_node: HtmlElement) -> str:
         """Safely retrieves the anchor tag for the document
 
+        :param  current_node: The relative lxml.HtmlElement
+        :returns: Anchor tag, if it's found
+        """
+        try:
+            if self._is_appellate():
+                path = f"{self._sibling_path('Document(s)')}//a"
+            else:
+                path = f"{self._sibling_path('Document Number')}//a"
+            return current_node.xpath(path)[0]
+        except IndexError:
+            return None
+
+    def _get_appellate_case_anchor(self) -> str:
+        """Safely retrieves the anchor tag for the appellate case
+
         :returns: Anchor tag, if it's found
         """
         try:
-            path = f"{self._sibling_path('Document Number')}//a"
+            path = f"{self._sibling_path('Case Number')}//a"
             return self.tree.xpath(path)[0]
         except IndexError:
             return None
 
-    def _get_description(self):
+    def _get_appellate_pacer_case_id(self) -> str:
+        """Extract the caseid from the appellate case anchor.
+
+        :returns: caseID, if it's found
+        """
+        document_url = self._get_appellate_case_anchor().xpath("./@href")[0]
+        match = re.search(r"caseId=(\d+)", document_url)
+        if match:
+            return match.group(1)
+        else:
+            return None
+
+    def _get_description(self, current_node: HtmlElement) -> str:
         """Gets the docket text
 
+        :param  current_node: The relative lxml.HtmlElement
         :returns: Cleaned docket text
         """
-        path = '//strong[contains(., "Docket Text:")]/following-sibling::'
-        node = self.tree.xpath(f"{path}font[1]/b//text()")
+
         description = ""
-        if len(node):
-            for des_part in node:
-                description = description + des_part
-            return clean_string(description)
+        # Paths to look for NEFs description
+        main_path = './following::strong[contains(., "Docket Text:")][1]/following-sibling::'
+        possible_paths = ["font[1]/b//text()", "b[1]/span//text()", "text()"]
 
-        node = self.tree.xpath(f"{path}b[1]/span//text()")
-        if len(node):
-            for des_part in node:
-                description = description + des_part
-            return clean_string(description)
+        if self._is_appellate():
+            # Paths to look for NDAs description
+            main_path = './following::strong[contains(., "Docket Text:")][1]/following::'
+            possible_paths = ["text()"]
+        for path in possible_paths:
+            node = current_node.xpath(f"{main_path}{path}")
+            if len(node):
+                for des_part in node:
+                    if self._is_appellate():
+                        if (
+                            des_part
+                            == "Notice will be electronically mailed to:"
+                        ):
+                            break
+                    description = description + des_part
+                description = clean_string(description)
+                if description:
+                    return description
 
-        return None
+        raise Exception(
+            f"Can't get docket entry description, court: {self.court_id}"
+        )
 
     def _get_description_plain(self):
         """Gets the docket text for plain email
@@ -198,15 +292,95 @@ class NotificationEmail(BaseDocketReport, BaseReport):
                 else:
                     # Stop looking for description lines
                     break
+        description = clean_string(description)
         if description:
-            return clean_string(description)
-        return None
+            return description
+        raise Exception(
+            f"Can't get docket entry description for court: {self.court_id}"
+        )
+
+    def _contains_attachments(self) -> bool:
+        """Determines if the html notification contains attached documents.
+
+        :returns: True if it contains otherwise False.
+        """
+
+        document_nodes = self.tree.xpath(
+            '//strong[contains(., "Document description:")]'
+        )
+        if len(document_nodes) <= 1:
+            return False
+        return True
+
+    def _contains_attachments_plain(self) -> bool:
+        """Determines if the plain/txt notification contains attached documents.
+
+        :returns: True if it contains otherwise False.
+        """
+
+        mail_body = self.tree.text_content()
+        regex = r"^.*?The following document\(s\) are associated with this transaction:(.*?)$"
+
+        find_attachments = re.findall(regex, mail_body, re.DOTALL)
+        associated_documents = 0
+        if find_attachments:
+            splitlines = find_attachments[0].splitlines()
+            for index_line in range(len(splitlines)):
+                if "Document description:" in splitlines[index_line]:
+                    associated_documents = +1
+        if associated_documents <= 1:
+            return False
+        return True
+
+    def _get_dockets(self) -> DocketType:
+        """Get all the dockets mentioned in the notification.
+
+        Right now multiple docket notifications are only supported for text/html
+        NEF notifications since we don't have examples for text/plain or NDAs
+        that mention multiple dockets. When we get one we'll log an error
+        and get the example.
+
+        :return: DocketType Dict
+        """
+        dockets = []
+        if self.content_type == "text/plain":
+            docket = {
+                "case_name": self._get_case_name_plain(),
+                "docket_number": self._get_docket_number_plain(),
+                "date_filed": self._get_date_filed(),
+                "docket_entries": self._get_docket_entries(),
+            }
+            dockets.append(docket)
+        else:
+            dockets_table = self.tree.xpath(
+                "//table[contains(., 'Case Name:')]"
+            )
+            if self.appellate and len(dockets_table) > 1:
+                raise NotImplementedError(
+                    f"Received a potential multi-docket NDA notification. "
+                    f"This is probably our chance to add support for it. "
+                    f"court: {self.court_id}"
+                )
+            for docket_table in dockets_table:
+                docket_number = self._get_docket_number(docket_table)
+                # Cache the docket number for its later use in
+                # _get_email_recipients_with_links
+                self.docket_numbers.append(docket_number)
+                docket = {
+                    "case_name": self._get_case_name(docket_table),
+                    "docket_number": docket_number,
+                    "date_filed": self._get_date_filed(),
+                    "docket_entries": self._get_docket_entries(docket_table),
+                }
+                dockets.append(docket)
+        return dockets
 
     def _get_docket_entries(
-        self,
-    ) -> List[Dict[str, Optional[Union[str, date]]]]:
+        self, current_node: HtmlElement = None
+    ) -> List[DocketEntryType]:
         """Gets the full list of docket entries with document and sequence numbers
 
+        :param  current_node: The relative lxml.HtmlElement
         :returns: List of docket entry dictionaries
         """
         if self.content_type == "text/plain":
@@ -221,13 +395,16 @@ class NotificationEmail(BaseDocketReport, BaseReport):
                     document_url = None
                 document_number = self._get_document_number_plain()
         else:
-            description = self._get_description()
+            description = self._get_description(current_node)
             if description is not None:
-                anchor = self._get_doc1_anchor()
+                anchor = self._get_doc1_anchor(current_node)
                 document_url = (
                     anchor.xpath("./@href")[0] if anchor is not None else None
                 )
-                document_number = self._get_document_number()
+                if self._is_appellate():
+                    document_number = None
+                else:
+                    document_number = self._get_document_number(current_node)
 
         if description is not None:
             entries = [
@@ -246,15 +423,22 @@ class NotificationEmail(BaseDocketReport, BaseReport):
                 entries[0]["pacer_doc_id"] = get_pacer_doc_id_from_doc1_url(
                     document_url
                 )
-                entries[0]["pacer_case_id"] = get_pacer_case_id_from_doc1_url(
-                    document_url
-                )
-                entries[0]["pacer_seq_no"] = get_pacer_seq_no_from_doc1_url(
-                    document_url
-                )
                 entries[0][
                     "pacer_magic_num"
-                ] = get_pacer_magic_num_from_doc1_url(document_url)
+                ] = get_pacer_magic_num_from_doc1_url(
+                    document_url, self.appellate
+                )
+                if not self._is_appellate():
+                    entries[0][
+                        "pacer_case_id"
+                    ] = get_pacer_case_id_from_doc1_url(document_url)
+                    entries[0][
+                        "pacer_seq_no"
+                    ] = get_pacer_seq_no_from_doc1_url(document_url)
+            if self._is_appellate():
+                entries[0][
+                    "pacer_case_id"
+                ] = self._get_appellate_pacer_case_id()
             return entries
         return []
 
@@ -289,7 +473,6 @@ class NotificationEmail(BaseDocketReport, BaseReport):
         :returns: List of email recipients with names and email addresses
         """
         # Matching names in this format is a bit less reliable. May be worth coming back to.
-        end_point = self._get_docket_number()
 
         replacements = [
             (r"\n", ""),
@@ -305,11 +488,14 @@ class NotificationEmail(BaseDocketReport, BaseReport):
                 r"^.*mailed\sto:",
                 "",
             ),
-            (
-                f"{re.escape(end_point)}.*$",
-                "",
-            ),
         ]
+        for end_point in self.docket_numbers:
+            replacements.append(
+                (
+                    f"{re.escape(end_point)}.*$",
+                    "",
+                )
+            )
 
         for replacement in replacements:
             text_content = re.sub(replacement[0], replacement[1], text_content)
@@ -346,15 +532,19 @@ class NotificationEmail(BaseDocketReport, BaseReport):
 
         :returns: List of email recipients with names and email addresses
         """
-        path = '//b[contains(., "Notice has been electronically mailed to")]/following-sibling::'
-        recipient_lines = self.tree.xpath(f"{path}text()")
-        link_lines = self.tree.xpath(f"{path}a")
-        if len(link_lines):
-            return self._get_email_recipients_with_links(
-                self.tree.xpath(
-                    'string(//b[contains(., "Notice has been electronically mailed to")]/parent::node())'
+        if self._is_appellate():
+            path = '//strong[contains(., "Notice will be electronically mailed to")]/following-sibling::'
+            recipient_lines = self.tree.xpath(f"{path}text()")
+        else:
+            path = '//b[contains(., "Notice has been electronically mailed to")]/following-sibling::'
+            recipient_lines = self.tree.xpath(f"{path}text()")
+            link_lines = self.tree.xpath(f"{path}a")
+            if len(link_lines):
+                return self._get_email_recipients_with_links(
+                    self.tree.xpath(
+                        'string(//b[contains(., "Notice has been electronically mailed to")]/parent::node())'
+                    )
                 )
-            )
         return self._get_email_recipients_with_links(" ".join(recipient_lines))
 
     def _get_email_recipients_plain(
@@ -456,7 +646,12 @@ class S3NotificationEmail(NotificationEmail):
                     self.content_type = "text/plain"
                     break
 
-        email_body = body.decode("UTF-8")
+        try:
+            # Try to decode email body using utf-8
+            email_body = body.decode("utf-8")
+        except UnicodeDecodeError:
+            # If it fails fallback on iso-8859-1
+            email_body = body.decode("iso-8859-1")
         if self.content_type == "text/plain":
             return super()._parse_text(email_body)
         elif self.content_type == "text/html":
