@@ -11,11 +11,12 @@ from ..lib.html_utils import (
     fix_links_in_lxml_tree,
     get_html5_parsed_text,
     get_html_parsed_text,
+    is_html,
     set_response_encoding,
     strip_bad_html_tags_insecure,
 )
 from ..lib.log_tools import make_default_logger
-from .utils import is_pdf, make_doc1_url
+from .utils import is_pdf, make_doc1_url, make_docs1_url
 
 logger = make_default_logger()
 
@@ -34,8 +35,6 @@ HtmlElement.re_xpath = re_xpath
 class BaseReport:
     """A base report for working with pages on PACER."""
 
-    REDIRECT_REGEX = re.compile(r'window\.\s*?location\s*=\s*"(.*)"\s*;')
-
     # Subclasses should override PATH
     PATH = ""
 
@@ -175,6 +174,7 @@ class BaseReport:
         pacer_case_id: str,
         pacer_doc_id: int,
         pacer_magic_num: Optional[str] = None,
+        appellate: bool = False,
     ) -> Tuple[Optional[Response], str]:
         """Download a PDF from PACER.
 
@@ -189,24 +189,46 @@ class BaseReport:
             # document anonymously by its magic link
 
             # Create PACER base url from court_id and pacer_doc_id
-            url = make_doc1_url(self.court_id, pacer_doc_id, True)
-
             # Magic link parameters
             # We don't need the de_seq_num parameter to fetch the free document
-            params = {
-                "caseid": pacer_case_id,
-                "magic_num": pacer_magic_num,
-            }
+            if appellate:
+                url = make_docs1_url(self.court_id, pacer_doc_id, True)
+                # For appellate documents the magic_number is the uid param
+                params = {
+                    "uid": pacer_magic_num,
+                }
+            else:
+                url = make_doc1_url(self.court_id, pacer_doc_id, True)
+                params = {
+                    "caseid": pacer_case_id,
+                    "magic_num": pacer_magic_num,
+                }
+
             # Add parameters to the PACER base url and make a GET request
             req_timeout = (60, 300)
             r = requests.get(url, params=params, timeout=req_timeout)
+
+            # If the response is an HTML document, and it doesn't contain an
+            # IFRAME, the magic link document is no longer available
+            error = None
+            if is_html(r) and "iframe" not in r.text:
+                error = (
+                    f"Document not available via magic link in case: "
+                    f"caseid: {pacer_case_id}, magic_num: {pacer_magic_num}, "
+                    f"URL: {url}"
+                )
+            if error:
+                logger.warning(error)
+                return None, error
+
         else:
             # If no magic_number use normal method to fetch the document
             r, url = self._query_pdf_download(
                 pacer_case_id, pacer_doc_id, pacer_magic_num, got_receipt="1"
             )
 
-            if "Cannot locate the case with caseid" in r.text:
+            # Use r.content instead of r.text for performance. See #564
+            if b"Cannot locate the case with caseid" in r.content:
                 # This document is from a different docket, but is included in
                 # this docket. Probably a criminal case with the doppelganger
                 # bug. Try again, but do so without the pacer_case_id.
@@ -216,44 +238,60 @@ class BaseReport:
                 )
 
             error = None
-            if "could not retrieve dktentry for dlsid" in r.text:
+            if b"could not retrieve dktentry for dlsid" in r.content:
                 error = (
                     f"Failed to get docket entry in case: "
                     f"{pacer_case_id=} at {url}"
                 )
-            if "This document is not available" in r.text:
+            if b"document is not available" in r.content:
+                # See: https://ecf.akb.uscourts.gov/doc1/02211536343
+                # See: https://ecf.ksd.uscourts.gov/doc1/07912639735
+                # Matches against:
+                # "The document is not available" and
+                # "This document is not available"
                 error = (
                     f"Document not available in case: "
                     f"{pacer_case_id=} at {url}"
                 )
             if re.search(
-                r"You do not have permission to view\s+this document.", r.text
+                rb"You do not have permission to view\s+this document.",
+                r.content,
             ):
                 error = (
-                    f"Permission denied getting document in case "
-                    f"{pacer_case_id=} at {url}. It's probably sealed."
+                    f"Permission denied getting document. It's probably "
+                    f"sealed. {pacer_case_id=}, {url=}"
                 )
-            if "You do not have access to this transcript." in r.text:
-                error = (
-                    f"Unable to get transcript at {url} in case "
-                    f"{pacer_doc_id=}."
-                )
-            if "Sealed Document" in r.text:
+            if b"You do not have access to this transcript." in r.content:
+                error = f"Unable to get transcript. {pacer_case_id=}, {url=}"
+            if b"Sealed Document" in r.content or b"Under Seal" in r.content:
                 # See: https://ecf.almd.uscourts.gov/doc1/01712589088
+                # See: https://ecf.cand.uscourts.gov/doc1/035122021132
+                # Matches against:
+                # "Sealed Document" and
+                # "This document is currently Under Seal and not available..."
                 error = f"Document is sealed: {pacer_case_id=} {url=}"
             if (
-                "This image is not available for viewing by non-court users"
-                in r.text
+                b"This image is not available for viewing by non-court users"
+                in r.content
             ):
                 # See: https://ecf.wvsd.uscourts.gov/doc1/20115419289
                 error = (
-                    f"Image not available for viewing by non-court users: "
-                    f"{pacer_case_id=} {url=}"
+                    f"Image not available for viewing by non-court users. "
+                    f"{pacer_case_id=}, {url=}"
                 )
-            if "A Client Code is required for PACER search" in r.text:
+            if b"A Client Code is required for PACER search" in r.content:
                 error = (
                     f"Unable to get document. Client code required: "
-                    f"{pacer_case_id} at {url}."
+                    f"{pacer_case_id=}, {url=}"
+                )
+            if (
+                b"Permission to view this document is denied based on Nature of Suit"
+                in r.content
+            ):
+                # See: https://ecf.cacd.uscourts.gov/doc1/031134206600
+                error = (
+                    f"Permission denied getting document due to nature of "
+                    f"suit. {pacer_case_id=}, {url=}"
                 )
 
             if error:
@@ -263,9 +301,11 @@ class BaseReport:
             # Some pacer sites use window.location in their JS, so we have to
             # look for that. See: oknd, 13-cv-00357-JED-FHM, doc #24. But, be
             # warned, you can only catch the redirection with JS off.
-            m = self.REDIRECT_REGEX.search(r.text)
+            redirect_re = re.compile(rb'window\.\s*?location\s*=\s*"(.*)"\s*;')
+            m = redirect_re.search(r.content)
             if m is not None:
-                r = self.session.get(urljoin(url, m.group(1)))
+                redirect_url = m.group(1).decode("utf-8")
+                r = self.session.get(urljoin(url, redirect_url))
                 r.raise_for_status()
 
         # The request above sometimes generates an HTML page with an iframe
